@@ -142,13 +142,17 @@ uptime()
 /* process age from jiffies to seconds via uptime */
 static double process_age(const unsigned long long jf)
 {
-   double sc_clk_tck = sysconf(_SC_CLK_TCK);
-   assert(sc_clk_tck > 0);
-   return uptime() - jf / sc_clk_tck;
+	double age;
+	double sc_clk_tck = sysconf(_SC_CLK_TCK);
+	assert(sc_clk_tck > 0);
+	age = uptime() - jf / sc_clk_tck;
+	if (age < 0L)
+		return 0L;
+	return age;
 }
 
 /* returns requested time interval in seconds, 
- negative indicates error has occured  
+ negative indicates error has occurred
  */
 static long
 parse_time_units(const char* age)
@@ -381,7 +385,6 @@ kill_all (int signal, int names, char **namelist, struct passwd *pwent)
 	    continue;
 	 }
 	 process_age_sec = process_age(proc_stt_jf);
-	 assert(process_age_sec >= 0L);
       }
       (void) fclose (file);
        
